pyexcel.internal.sheets.Matrix
==============================

.. currentmodule:: pyexcel.internal.sheets

.. autoclass:: Matrix

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Matrix.__init__
      ~Matrix.cell_value
      ~Matrix.clone
      ~Matrix.column_at
      ~Matrix.column_range
      ~Matrix.columns
      ~Matrix.contains
      ~Matrix.cut
      ~Matrix.delete_columns
      ~Matrix.delete_rows
      ~Matrix.enumerate
      ~Matrix.extend_columns
      ~Matrix.extend_columns_with_rows
      ~Matrix.extend_rows
      ~Matrix.filter
      ~Matrix.format
      ~Matrix.get_array
      ~Matrix.get_bookdict
      ~Matrix.get_csv
      ~Matrix.get_csvz
      ~Matrix.get_dict
      ~Matrix.get_fods
      ~Matrix.get_grid
      ~Matrix.get_handsontable
      ~Matrix.get_handsontable_html
      ~Matrix.get_html
      ~Matrix.get_internal_array
      ~Matrix.get_json
      ~Matrix.get_latex
      ~Matrix.get_latex_booktabs
      ~Matrix.get_mediawiki
      ~Matrix.get_ndjson
      ~Matrix.get_ods
      ~Matrix.get_orgtbl
      ~Matrix.get_pipe
      ~Matrix.get_plain
      ~Matrix.get_records
      ~Matrix.get_rst
      ~Matrix.get_simple
      ~Matrix.get_svg
      ~Matrix.get_texttable
      ~Matrix.get_tsv
      ~Matrix.get_tsvz
      ~Matrix.get_url
      ~Matrix.get_xls
      ~Matrix.get_xlsm
      ~Matrix.get_xlsx
      ~Matrix.map
      ~Matrix.number_of_columns
      ~Matrix.number_of_rows
      ~Matrix.paste
      ~Matrix.plot
      ~Matrix.rcolumns
      ~Matrix.region
      ~Matrix.register_input
      ~Matrix.register_io
      ~Matrix.register_presentation
      ~Matrix.reverse
      ~Matrix.row_at
      ~Matrix.row_range
      ~Matrix.rows
      ~Matrix.rrows
      ~Matrix.rvertical
      ~Matrix.save_as
      ~Matrix.save_to_database
      ~Matrix.save_to_django_model
      ~Matrix.save_to_memory
      ~Matrix.set_array
      ~Matrix.set_bookdict
      ~Matrix.set_column_at
      ~Matrix.set_csv
      ~Matrix.set_csvz
      ~Matrix.set_dict
      ~Matrix.set_fods
      ~Matrix.set_grid
      ~Matrix.set_handsontable
      ~Matrix.set_handsontable_html
      ~Matrix.set_html
      ~Matrix.set_json
      ~Matrix.set_latex
      ~Matrix.set_latex_booktabs
      ~Matrix.set_mediawiki
      ~Matrix.set_ndjson
      ~Matrix.set_ods
      ~Matrix.set_orgtbl
      ~Matrix.set_pipe
      ~Matrix.set_plain
      ~Matrix.set_records
      ~Matrix.set_row_at
      ~Matrix.set_rst
      ~Matrix.set_simple
      ~Matrix.set_svg
      ~Matrix.set_texttable
      ~Matrix.set_tsv
      ~Matrix.set_tsvz
      ~Matrix.set_url
      ~Matrix.set_xls
      ~Matrix.set_xlsm
      ~Matrix.set_xlsx
      ~Matrix.to_array
      ~Matrix.transpose
      ~Matrix.vertical
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Matrix.array
      ~Matrix.bookdict
      ~Matrix.csv
      ~Matrix.csvz
      ~Matrix.dict
      ~Matrix.fods
      ~Matrix.grid
      ~Matrix.handsontable
      ~Matrix.handsontable_html
      ~Matrix.html
      ~Matrix.json
      ~Matrix.latex
      ~Matrix.latex_booktabs
      ~Matrix.mediawiki
      ~Matrix.ndjson
      ~Matrix.ods
      ~Matrix.orgtbl
      ~Matrix.pipe
      ~Matrix.plain
      ~Matrix.records
      ~Matrix.rst
      ~Matrix.simple
      ~Matrix.stream
      ~Matrix.svg
      ~Matrix.texttable
      ~Matrix.tsv
      ~Matrix.tsvz
      ~Matrix.url
      ~Matrix.xls
      ~Matrix.xlsm
      ~Matrix.xlsx
   
   